==> Smdn.Net.Imap4.Client-0.21.tar.bz2: Smdn.Net.Imap4.Client-0.21/Smdn.Net.Imap4.Client/Smdn.Net.Imap4.Client.Transaction.BuiltIn/IdTransaction.cs <==
// 
// Author:
//       smdn <smdn@mail.invisiblefulmoon.net>
// 
// Copyright (c) 2008-2009 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Collections.Generic;

using Smdn.Net.Imap4.Protocol;
using Smdn.Net.Imap4.Protocol.Client;

namespace Smdn.Net.Imap4.Client.Transaction.BuiltIn {
  internal class IdTransaction : ImapTransactionBase<ImapTransactionResult<Dictionary<string, string>>>, IImapExtension {
    ImapCapability IImapExtension.RequiredCapability {
      get { return ImapCapability.ID; }
    }

    public IdTransaction(ImapConnection connection)
      : base(connection)
    {
    }

    protected override ProcessTransactionDelegate Reset()
    {
      return ProcessId;
    }

    // 3.1. ID Command
    //    Arguments:  client parameter list or NIL
    //    Responses:  OPTIONAL untagged response: ID
    //    Result:     OK    identification information accepted
    //                BAD   command unknown or arguments invalid
    private void ProcessId()
    {
      if (Request.Arguments.ContainsKey("client parameter list"))
        SendCommand("ID", ProcessReceiveResponse, Request.Arguments["client parameter list"]);
      else
        SendCommand("ID", ProcessReceiveResponse, new ImapNilString());
    }

    protected override void OnDataResponseReceived(ImapDataResponse data)
    {
      if (data.Type == ImapDataResponseType.Id)
        serverParameterList = ImapDataResponseConverter.FromId(data);

      base.OnDataResponseReceived(data);
    }

    protected override void OnTaggedStatusResponseReceived(ImapTaggedStatusResponse tagged)
    {
      if (tagged.Condition == ImapResponseCondition.Ok)
        Finish(new ImapTransactionResult<Dictionary<string, string>>(serverParameterList, tagged.ResponseText.Text));
      else
        base.OnTaggedStatusResponseReceived(tagged);
    }

    private Dictionary<string, string> serverParameterList = new Dictionary<string, string>();
  }
}

==> Smdn.Net.Imap4.Client-0.32.tar.bz2: Smdn.Net.Imap4.Client-0.32/Smdn.Net.Imap4.Client/Smdn.Net.Imap4.Client.Transaction.BuiltIn/IdTransaction.cs <==
// 
// Author:
//       smdn <smdn@mail.invisiblefulmoon.net>
// 
// Copyright (c) 2008-2010 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Collections.Generic;

using Smdn.Collections;
using Smdn.Net.Imap4.Protocol;
using Smdn.Net.Imap4.Protocol.Client;

namespace Smdn.Net.Imap4.Client.Transaction.BuiltIn {
  internal sealed class IdTransaction : ImapTransactionBase<ImapCommandResult<IDictionary<string, string>>>, IImapExtension {
    ImapCapability IImapExtension.RequiredCapability {
      get { return ImapCapability.ID; }
    }

    public IdTransaction(ImapConnection connection)
      : base(connection)
    {
    }

    protected override ProcessTransactionDelegate Reset()
    {
      return ProcessId;
    }

    // 3.1. ID Command
    //    Arguments:  client parameter list or NIL
    //    Responses:  OPTIONAL untagged response: ID
    //    Result:     OK    identification information accepted
    //                BAD   command unknown or arguments invalid
    private void ProcessId()
    {
      ImapString clientParameterList;

      if (RequestArguments.TryGetValue("client parameter list", out clientParameterList))
        SendCommand("ID", ProcessReceiveResponse, clientParameterList);
      else
        SendCommand("ID", ProcessReceiveResponse, new ImapNilString());
    }

    protected override void OnDataResponseReceived(ImapDataResponse data)
    {
      if (data.Type == ImapDataResponseType.Id)
        serverParameterList = ImapDataResponseConverter.FromId(data);

      base.OnDataResponseReceived(data);
    }

    protected override void OnTaggedStatusResponseReceived(ImapTaggedStatusResponse tagged)
    {
      if (tagged.Condition == ImapResponseCondition.Ok) {
        if (serverParameterList == null)
          serverParameterList = new Dictionary<string, string>(StringComparer.OrdinalIgnoreCase);

        Finish(new ImapCommandResult<IDictionary<string, string>>(serverParameterList.AsReadOnly(),
                                                                  tagged.ResponseText));
      }
      else {
        base.OnTaggedStatusResponseReceived(tagged);
      }
    }

    private IDictionary<string, string> serverParameterList = null;
  }
}
